#ifndef __HD_DATA2_H
# define __HD_DATA2_H
/*!
*  \file hd-data2.h
*  \brief All other A-C countries data which is composed into the
*               eternal holiday list header file.
*/
/*
*  Copyright (c) 1994, 95, 96, 1997, 2000 Thomas Esken
*  Copyright (c) 2010, 2011, 2013 Free Software Foundation, Inc.
*
*  This software doesn't claim completeness, correctness or usability.
*  On principle I will not be liable for ANY damages or losses (implicit
*  or explicit), which result from using or handling my software.
*  If you use this software, you agree without any exception to this
*  agreement, which binds you LEGALLY !!
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the `GNU General Public License' as published by
*  the `Free Software Foundation'; either version 3, or (at your option)
*  any later version.
*
*  You should have received a copy of the `GNU General Public License'
*  along with this program; if not, write to the:
*
*/



/*
*  $Id: hd-data2.h 3.01 2000/06/14 03:00:01 tom Exp $
*/



/*
*  GLOBAL functions prototypes.
*/
__BEGIN_DECLARATIONS
/*
************************************************** Defined in `hd-data2.c'.
*/
extern void
  ad_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ae_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  af_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ag_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ai_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  al_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  am_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  an_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  an_bo_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  an_cu_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  an_ma_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  an_sa_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ao_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ar_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  as_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  at_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  at_vo_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  at_ti_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  at_sa_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  at_ka_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  at_st_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  at_oo_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  at_no_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  at_bu_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  at_wi_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  au_ct_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  au_nt_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  au_qu_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  au_sa_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  au_sw_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  au_ta_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  au_vi_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  au_wa_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  aw_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  az_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ba_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bb_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bd_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bf_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bg_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bh_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bi_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bj_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bm_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bn_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bo_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bs_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bt_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bv_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bw_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  by_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  bz_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ca_al_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ca_bc_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ca_ma_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ca_nb_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ca_nf_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ca_ns_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ca_nw_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ca_on_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ca_pe_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ca_qu_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ca_sa_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ca_yu_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  cc_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  cd_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  cf_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  cg_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ch_ar_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_ag_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_ai_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_bl_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_be_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_bs_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_fr_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_gr_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_gl_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_ge_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_ju_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_lu_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_ne_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_nw_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_ow_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_sg_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_sh_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_so_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_sz_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_ti_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_tg_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_ur_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_vd_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_vs_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_zg_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ch_zh_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  ci_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ck_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  cl_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  cm_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  co_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  cr_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  cu_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  cv_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  cx_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  cy_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  cz_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
__END_DECLARATIONS
#endif /* __HD_DATA2_H */
